"use strict";
/**
 * @module botframework-streaming
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeWebSocketFactory = void 0;
const nodeWebSocket_1 = require("../nodeWebSocket");
const nodeWebSocketFactoryBase_1 = require("./nodeWebSocketFactoryBase");
/**
 * Represents a NodeWebSocketFactory to create a WebSocket server.
 */
class NodeWebSocketFactory extends nodeWebSocketFactoryBase_1.NodeWebSocketFactoryBase {
    /**
     * Initializes a new instance of the [NodeWebSocketFactory](xref:botframework-streaming.NodeWebSocketFactory) class.
     */
    constructor() {
        super();
    }
    /**
     * Creates a [NodeWebSocket](xref:botframework-streaming.NodeWebSocket) instance.
     *
     * @remarks
     * The parameters for this method should be associated with an 'upgrade' event off of a Node.js HTTP Server.
     * @param req An IncomingMessage from the 'http' module in Node.js.
     * @param socket The Socket connecting the bot and the server, from the 'net' module in Node.js.
     * @param head The first packet of the upgraded stream which may be empty per https://nodejs.org/api/http.html#http_event_upgrade_1.
     * @returns A [NodeWebSocket](xref:botframework-streaming.NodeWebSocket) instance ready for streaming.
     */
    createWebSocket(req, socket, head) {
        return __awaiter(this, void 0, void 0, function* () {
            const s = new nodeWebSocket_1.NodeWebSocket();
            yield s.create(req, socket, head);
            return s;
        });
    }
}
exports.NodeWebSocketFactory = NodeWebSocketFactory;
//# sourceMappingURL=nodeWebSocketFactory.js.map